@@ -32,7 +32,7 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
+
 import datetime
 from operator import itemgetter
 
@@ -152,10 +152,6 @@ class GithubObject(object):
     def _makeIntAttribute(value):
         return GithubObject.__makeSimpleAttribute(value, six.integer_types)
 
-    @staticmethod
-    def _makeFloatAttribute(value):
-        return GithubObject.__makeSimpleAttribute(value, float)
-
     @staticmethod
     def _makeBoolAttribute(value):
         return GithubObject.__makeSimpleAttribute(value, bool)
@@ -237,11 +233,11 @@ class GithubObject(object):
                 if isinstance(v, bytes):
                     v = v.decode('utf-8')
                 if isinstance(v, six.text_type):
-                    v = u'"{v}"'.format(v=v)
-                yield u'{k}={v}'.format(k=k, v=v)
-        return u'{class_name}({params})'.format(
+                    v = '"{v}"'.format(v=v)
+                yield '{k}={v}'.format(k=k, v=v)
+        return '{class_name}({params})'.format(
             class_name=self.__class__.__name__,
-            params=u", ".join(list(format_params(params)))
+            params=", ".join(list(format_params(params)))
         )
 
 
