@@ -30,6 +30,7 @@
 #                                                                              #
 ################################################################################
 
+
 import datetime
 
 import github.GithubObject
@@ -37,6 +38,7 @@ import github.PaginatedList
 
 import github.NamedUser
 import github.Label
+import six
 
 
 class Milestone(github.GithubObject.CompletableGithubObject):
@@ -170,9 +172,9 @@ class Milestone(github.GithubObject.CompletableGithubObject):
         :param due_on: date
         :rtype: None
         """
-        assert isinstance(title, str), title
-        assert state is github.GithubObject.NotSet or isinstance(state, str), state
-        assert description is github.GithubObject.NotSet or isinstance(description, str), description
+        assert isinstance(title, (str, six.text_type)), title
+        assert state is github.GithubObject.NotSet or isinstance(state, (str, six.text_type)), state
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, six.text_type)), description
         assert due_on is github.GithubObject.NotSet or isinstance(due_on, datetime.date), due_on
         post_parameters = {
             "title": title,
